//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import React from "react";
import { isNonEmptyString, COLORS, newGuid } from "primeobjects-helper-util";
import { getGlobalComponent, setGlobalComponent } from "primeobjects-ui-web-application/build/cjs/util";
import { isNumber } from "lodash";
import { getTemperatureRows } from "../rows/ai/temperature-rows";
import { getMaxResultLengthRows, MAX_RESULT_LENGTH_VALUE } from "../rows/ai/max-result-length-rows";
import AiStream from "primeobjects-ui-web-application/build/cjs/controls/ai-stream";
import Lottie from "primeobjects-ui-web-basic/build/cjs/controls/lottie";
import { sendEvent } from "primeobjects-ui-web-basic/build/cjs/hooks/use-event";
var DEFAULT_SUMMARY_COMMAND = "Tl;dr, summarize in one paragraph without bullet";
export var getForm = function (props) {
    var _a;
    var isError = props.isError, onDoing = props.onDoing, onError = props.onError, toChangeRecord = props.toChangeRecord, entity = props.entity, fieldNameForSummary = props.fieldNameForSummary;
    var sectionWrapperStyle = (_a = props.sectionWrapperStyle) !== null && _a !== void 0 ? _a : {};
    var getRows = function (record) {
        var aiStream = getGlobalComponent("run-command-summarize");
        var getSummaryContent = function () {
            if (fieldNameForSummary &&
                isNonEmptyString(record[fieldNameForSummary])) {
                return convertHtmlToText(record[fieldNameForSummary]);
            }
            if (entity.fieldNameForSummary &&
                isNonEmptyString(record[entity.fieldNameForSummary])) {
                return convertHtmlToText(record[entity.fieldNameForSummary]);
            }
            if (isNonEmptyString(record.content))
                return convertHtmlToText(record.content);
            if (isNonEmptyString(record.description))
                return convertHtmlToText(record.description);
            if (isNonEmptyString(record.detail))
                return convertHtmlToText(record.detail);
            return "";
        };
        var convertHtmlToText = function (content) {
            var div = document.createElement("div");
            div.innerHTML = content
                .replace(new RegExp("</p>", "g"), "</p>\n")
                .replace(new RegExp("</div>", "g"), "</div>\n")
                .replace(new RegExp("<br>", "g"), "<br>\n")
                .replace(new RegExp("<br/>", "g"), "<br/>\n");
            return div.innerText
                .replace(new RegExp("(\n){2,}", "g"), "\n")
                .replace(new RegExp("( ){2,}", "g"), " ")
                .trim();
        };
        var getErrorMessage = function () {
            if (isError("run-command-summarize", "no-content")) {
                return "There is no content provided.";
            }
            if (isError("run-command-summarize", "missing-parameter")) {
                return "There is no value in one of the parameters.";
            }
            if (isError("run-command-summarize", "ai-stream-failed")) {
                return "Sorry, our AI failed to summarize the content, please check whether you still have enough credits or try again later ...";
            }
            return "";
        };
        var errorMessage = getErrorMessage();
        var streaming = !isNonEmptyString(errorMessage) &&
            aiStream &&
            aiStream.id == "summarize" &&
            aiStream.assistant;
        var onErrorAIStream = function (error) {
            console.error(error);
            onDoing("run-command-summarize", false);
            onError("run-command-summarize", "ai-stream-failed", error);
        };
        var onFinishAIStream = function (summary) {
            toChangeRecord(__assign(__assign({}, record), { summary: summary }));
            setGlobalComponent("run-command-summarize", null);
            onDoing("run-command-summarize", false);
            sendEvent("ai-credit-update-channel", Date.now());
        };
        var onClickSubmitButton = function () {
            var _a;
            var content = getSummaryContent();
            toChangeRecord(__assign(__assign({}, record), { summary: "" }));
            if (!isNonEmptyString(content)) {
                return onError("run-command-summarize", "no-content");
            }
            var assistant = {
                id: "summarize",
                transactionId: newGuid(),
                start: Date.now(),
                content: content,
                command: DEFAULT_SUMMARY_COMMAND,
                maxResultLength: (_a = record.aiSummarizeMaxResultLength) !== null && _a !== void 0 ? _a : MAX_RESULT_LENGTH_VALUE,
                temperature: isNumber(record.aiSummarizeTemperature)
                    ? record.aiSummarizeTemperature
                    : 0,
                model: "text-davinci-003",
                bestOf: 1,
                commandRequireContent: true
            };
            setGlobalComponent("run-command-summarize", {
                id: "summarize",
                assistant: assistant
            });
            onError("run-command-summarize", false);
            onDoing("run-command-summarize", true);
        };
        return __spreadArray(__spreadArray(__spreadArray([
            {
                style: { paddingBottom: 0 },
                fields: [
                    {
                        name: "summary",
                        line: "Summary",
                        subLine: (React.createElement("div", { className: "flex flex-row" }, "You can manually provide summary or press\n                                    the \"Summarize by AI\" button to ask help\n                                    from our smart AI assistant. Please always\n                                    review the result before publishing it.")),
                        type: "section",
                        wrapperStyle: __assign({ marginTop: 0 }, sectionWrapperStyle)
                    }
                ]
            }
        ], getTemperatureRows(__assign(__assign({}, props), { fieldName: "aiSummarizeTemperature", value: isNumber(record.aiSummarizeTemperature)
                ? record.aiSummarizeTemperature
                : 0, tab: "run" })), true), getMaxResultLengthRows(__assign(__assign({}, props), { fieldName: "aiSummarizeMaxResultLength", value: isNumber(record.aiSummarizeMaxResultLength)
                ? record.aiSummarizeMaxResultLength
                : MAX_RESULT_LENGTH_VALUE, tab: "run" })), true), [
            !streaming && {
                style: { paddingTop: "1rem" },
                fields: [
                    {
                        name: "playgroundResultStream",
                        type: "container",
                        content: (React.createElement("div", { className: "flex flex-col justify-end" },
                            React.createElement("div", { className: "flex w-32 mt-2 rounded-md cursor-pointer text-white px-1 py-2 shadow hover:shadow-lg text-white justify-center items-center leading-none bg-sky-400 hover:bg-sky-500", onClick: onClickSubmitButton }, "Summarize by AI")))
                    }
                ]
            },
            {
                className: "mt-4",
                style: { paddingBottom: "0.5rem" },
                fields: [
                    {
                        name: "summaryLabel",
                        line: "Summary",
                        type: "label"
                    }
                ]
            },
            streaming && {
                style: { paddingBottom: 0 },
                fields: [
                    {
                        name: "playgroundResultStream",
                        type: "container",
                        content: (React.createElement("div", { className: "flex flex-row w-full items-center" },
                            React.createElement("div", { className: "h-6" },
                                React.createElement(Lottie, { className: "w-full h-full", url: "/icons/platform/lottie/dots-2.json", colors: Array(6).fill(COLORS.GRAY[700]) })),
                            React.createElement("div", { className: "flex-1 text-sm text-gray-700 p-2" }, "Processing the content ...")))
                    }
                ]
            },
            !streaming &&
                isNonEmptyString(errorMessage) && {
                fields: [
                    {
                        name: "summarizeFailed",
                        type: "alert-error",
                        line: errorMessage
                    }
                ]
            },
            streaming && {
                fields: [
                    {
                        name: "playgroundResultStream",
                        type: "container",
                        content: (React.createElement(AiStream, { assistant: aiStream.assistant, className: "w-full text-base", onFinish: onFinishAIStream, onError: onErrorAIStream, rows: 3 }))
                    }
                ]
            },
            !isNonEmptyString(errorMessage) &&
                !streaming && {
                fields: [
                    {
                        name: "summary",
                        type: "html",
                        placeholder: "Type the summary here"
                    }
                ]
            }
        ], false);
    };
    return {
        id: "summarize",
        tooltip: "Summarize",
        getRows: getRows,
        iconSrc: "/icons/platform/summary.svg",
        alwaysShowLabel: true
    };
};
//# sourceMappingURL=summary-form.js.map